==> fetch.php?media=uls%3Auls_update-1.9.5.tgz: update/von_1.9.4/sql/limitgroupelement_trigger.sql <==
set @@character_set_client = 'utf8';

delimiter //

drop trigger if exists limitgroupelement_au//
create trigger limitgroupelement_au after update on limitgroupelement
  for each row 
begin
  if NEW.limtype = 'L' then
    insert into changeprot
      (groupID, changedtable, tableID, parentID, userID, username, action,
       domain, classes, server, section, teststep, newvalues)
    select limitgroup.groupID, 'limitgroupelement', NEW.ID, NEW.limitgroupID, coalesce(@userid,0),
      coalesce(@username,'SYSTEM'), 'update', showreg(NEW.domain, NEW.domain_v),
      showreg(NEW.classes, NEW.classes_v), showreg(NEW.server, NEW.server_v),
      showreg(NEW.section, NEW.section_v), showreg(NEW.teststep, NEW.teststep_v),
      concat('limitgroup=', limitgroup.name, '\nname=', NEW.name, '\nlimit=limit:',
             if(g.bemerkungen = '',
                concat(showreg(g.domain, g.domain_v), '|', showreg(g.classes, g.classes_v), '|',
                       showreg(g.server, g.server_v), '|', showreg(g.section, g.section_v), '|',
                       showreg(g.teststep, g.teststep_v)),
                substring_index(g.bemerkungen, '\n', 1)),
             '\nmingood=', NEW.mingood, '\nwarngood=', NEW.warngood, '\nwarngoodlevel=', NEW.warngoodlevel,
             '\nsetclass=', coalesce((select sc.name from serverclasses as sc where sc.ID = NEW.resultingclassID), ''),
             '\nremark=', REPLACE(REPLACE(NEW.remark, '\\', '\\\\'), '\n', '\\n'), '\nactive=', NEW.active)
    from gautolimits as g, limitgroup
    where NEW.TS != OLD.TS and g.ID = NEW.groupautoID and limitgroup.ID = NEW.limitgroupID;
  elseif NEW.limtype = 'I' then
    insert into changeprot
      (groupID, changedtable, tableID, parentID, userID, username, action,
       domain, classes, server, section, teststep, newvalues)
    select limitgroup.groupID, 'limitgroupelement', NEW.ID, NEW.limitgroupID, coalesce(@userid,0),
      coalesce(@username,'SYSTEM'), 'update', showreg(NEW.domain, NEW.domain_v),
      showreg(NEW.classes, NEW.classes_v), showreg(NEW.server, NEW.server_v),
      showreg(NEW.section, NEW.section_v), showreg(NEW.teststep, NEW.teststep_v),
      concat('limitgroup=', limitgroup.name, '\nname=', NEW.name, '\nlimit=isalive:',
             if(g.bemerkungen = '',
                concat(showreg(g.domain, g.domain_v), '|', showreg(g.classes, g.classes_v), '|',
                       showreg(g.server, g.server_v), '|', showreg(g.section, g.section_v), '|',
                       showreg(g.teststep, g.teststep_v)),
                substring_index(g.bemerkungen, '\n', 1)),
             '\nmingood=', NEW.mingood, '\nwarngood=', NEW.warngood, '\nwarngoodlevel=', NEW.warngoodlevel,
             '\nsetclass=', coalesce((select sc.name from serverclasses as sc where sc.ID = NEW.resultingclassID), ''),
             '\nremark=', REPLACE(REPLACE(NEW.remark, '\\', '\\\\'), '\n', '\\n'), '\nactive=', NEW.active)
    from gautoisalive as g, limitgroup
    where NEW.TS != OLD.TS and g.ID = NEW.groupautoID and limitgroup.ID = NEW.limitgroupID;
  elseif NEW.limtype = 'C' then
    insert into changeprot
      (groupID, changedtable, tableID, parentID, userID, username, action,
       domain, classes, server, section, teststep, newvalues)
    select limitgroup.groupID, 'limitgroupelement', NEW.ID, NEW.limitgroupID, coalesce(@userid,0),
      coalesce(@username,'SYSTEM'), 'update', showreg(NEW.domain, NEW.domain_v),
      showreg(NEW.classes, NEW.classes_v), showreg(NEW.server, NEW.server_v),
      showreg(NEW.section, NEW.section_v), showreg(NEW.teststep, NEW.teststep_v),
      concat('limitgroup=', limitgroup.name, '\nname=', NEW.name, '\nlimit=combilimit:',
             if(g.bemerkungen = '',
                concat(showreg(g.domain, g.domain_v), '|', showreg(g.classes, g.classes_v), '|',
                       showreg(g.server, g.server_v), '|', showreg(g.section, g.section_v), '|',
                       showreg(g.teststep, g.teststep_v)),
                substring_index(g.bemerkungen, '\n', 1)),
             '\nmingood=', NEW.mingood, '\nwarngood=', NEW.warngood, '\nwarngoodlevel=', NEW.warngoodlevel,
             '\nsetclass=', coalesce((select sc.name from serverclasses as sc where sc.ID = NEW.resultingclassID), ''),
             '\nremark=', REPLACE(REPLACE(NEW.remark, '\\', '\\\\'), '\n', '\\n'), '\nactive=', NEW.active)
    from gautocombilimits as g, limitgroup
    where NEW.TS != OLD.TS and g.ID = NEW.groupautoID and limitgroup.ID = NEW.limitgroupID;
  end if;
end//

drop trigger if exists limitgroupelement_ai//
create trigger limitgroupelement_ai after insert on limitgroupelement
  for each row 
begin
  if NEW.limtype = 'L' then
    insert into changeprot
      (groupID, changedtable, tableID, parentID, userID, username, action,
       domain, classes, server, section, teststep, newvalues)
    select limitgroup.groupID, 'limitgroupelement', NEW.ID, NEW.limitgroupID, coalesce(@userid,0),
      coalesce(@username,'SYSTEM'), 'insert', showreg(NEW.domain, NEW.domain_v),
      showreg(NEW.classes, NEW.classes_v), showreg(NEW.server, NEW.server_v),
      showreg(NEW.section, NEW.section_v), showreg(NEW.teststep, NEW.teststep_v),
      concat('limitgroup=', limitgroup.name, '\nname=', NEW.name, '\nlimit=limit:',
             if(g.bemerkungen = '',
                concat(showreg(g.domain, g.domain_v), '|', showreg(g.classes, g.classes_v), '|',
                       showreg(g.server, g.server_v), '|', showreg(g.section, g.section_v), '|',
                       showreg(g.teststep, g.teststep_v)),
                substring_index(g.bemerkungen, '\n', 1)),
             '\nmingood=', NEW.mingood, '\nwarngood=', NEW.warngood, '\nwarngoodlevel=', NEW.warngoodlevel,
             '\nsetclass=', coalesce((select sc.name from serverclasses as sc where sc.ID = NEW.resultingclassID), ''),
             '\nremark=', REPLACE(REPLACE(NEW.remark, '\\', '\\\\'), '\n', '\\n'), '\nactive=', NEW.active)
    from gautolimits as g, limitgroup
    where g.ID = NEW.groupautoID and limitgroup.ID = NEW.limitgroupID;
  elseif NEW.limtype = 'I' then
    insert into changeprot
      (groupID, changedtable, tableID, parentID, userID, username, action,
       domain, classes, server, section, teststep, newvalues)
    select limitgroup.groupID, 'limitgroupelement', NEW.ID, NEW.limitgroupID, coalesce(@userid,0),
      coalesce(@username,'SYSTEM'), 'insert', showreg(NEW.domain, NEW.domain_v),
      showreg(NEW.classes, NEW.classes_v), showreg(NEW.server, NEW.server_v),
      showreg(NEW.section, NEW.section_v), showreg(NEW.teststep, NEW.teststep_v),
      concat('limitgroup=', limitgroup.name, '\nname=', NEW.name, '\nlimit=isalive:',
             if(g.bemerkungen = '',
                concat(showreg(g.domain, g.domain_v), '|', showreg(g.classes, g.classes_v), '|',
                       showreg(g.server, g.server_v), '|', showreg(g.section, g.section_v), '|',
                       showreg(g.teststep, g.teststep_v)),
                substring_index(g.bemerkungen, '\n', 1)),
             '\nmingood=', NEW.mingood, '\nwarngood=', NEW.warngood, '\nwarngoodlevel=', NEW.warngoodlevel,
             '\nsetclass=', coalesce((select sc.name from serverclasses as sc where sc.ID = NEW.resultingclassID), ''),
             '\nremark=', REPLACE(REPLACE(NEW.remark, '\\', '\\\\'), '\n', '\\n'), '\nactive=', NEW.active)
    from gautoisalive as g, limitgroup
    where g.ID = NEW.groupautoID and limitgroup.ID = NEW.limitgroupID;
  elseif NEW.limtype = 'C' then
    insert into changeprot
      (groupID, changedtable, tableID, parentID, userID, username, action,
       domain, classes, server, section, teststep, newvalues)
    select limitgroup.groupID, 'limitgroupelement', NEW.ID, NEW.limitgroupID, coalesce(@userid,0),
      coalesce(@username,'SYSTEM'), 'insert', showreg(NEW.domain, NEW.domain_v),
      showreg(NEW.classes, NEW.classes_v), showreg(NEW.server, NEW.server_v),
      showreg(NEW.section, NEW.section_v), showreg(NEW.teststep, NEW.teststep_v),
      concat('limitgroup=', limitgroup.name, '\nname=', NEW.name, '\nlimit=combilimit:',
             if(g.bemerkungen = '',
                concat(showreg(g.domain, g.domain_v), '|', showreg(g.classes, g.classes_v), '|',
                       showreg(g.server, g.server_v), '|', showreg(g.section, g.section_v), '|',
                       showreg(g.teststep, g.teststep_v)),
                substring_index(g.bemerkungen, '\n', 1)),
             '\nmingood=', NEW.mingood, '\nwarngood=', NEW.warngood, '\nwarngoodlevel=', NEW.warngoodlevel,
             '\nsetclass=', coalesce((select sc.name from serverclasses as sc where sc.ID = NEW.resultingclassID), ''),
             '\nremark=', REPLACE(REPLACE(NEW.remark, '\\', '\\\\'), '\n', '\\n'), '\nactive=', NEW.active)
    from gautocombilimits as g, limitgroup
    where g.ID = NEW.groupautoID and limitgroup.ID = NEW.limitgroupID;
  end if;
end//


drop trigger if exists limitgroupelement_bd//
create trigger limitgroupelement_bd before delete on limitgroupelement
  for each row 
begin
  insert into changeprot
    (groupID, changedtable, tableID, parentID, userID, username, action,
     domain, classes, server, section, teststep, newvalues)
  select limitgroup.groupID, 'limitgroupelement', OLD.ID, OLD.limitgroupID,
     coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'delete', showreg(OLD.domain, OLD.domain_v),
     showreg(OLD.classes, OLD.classes_v), showreg(OLD.server, OLD.server_v),
     showreg(OLD.section, OLD.section_v), showreg(OLD.teststep, OLD.teststep_v),
     concat('limitgroup=', limitgroup.name, '\nname=', OLD.name,
            coalesce(concat('\nremark=', REPLACE(REPLACE(@limitgroupremark, '\\', '\\\\'), '\n', '\\n')),
                     concat('\nremark=', REPLACE(REPLACE(@limitgroupelementremark, '\\', '\\\\'), '\n', '\\n')),''))
  from limitgroup
  where limitgroup.ID = OLD.limitgroupID;
end//

delimiter ;

==> fetch.php?media=uls%3Auls_update-1.9.6.tgz: update/von_1.9.5/sql/limitgroupelement_trigger.sql <==
set @@character_set_client = 'utf8';

delimiter //

drop trigger if exists limitgroupelement_au//
create trigger limitgroupelement_au after update on limitgroupelement
  for each row
begin
  if NEW.limtype = 'L' then
    insert into changeprot
      (groupID, changedtable, tableID, parentID, userID, username, action,
       domain, classes, server, section, teststep, newvalues)
    select limitgroup.groupID, 'limitgroupelement', limitgroupelement.ID, limitgroupID, coalesce(@userid,0),
      coalesce(@username,'SYSTEM'), 'update', showreg(limitgroupelement.domain, limitgroupelement.domain_v),
      showreg(limitgroupelement.classes, limitgroupelement.classes_v), showreg(limitgroupelement.server, limitgroupelement.server_v),
      showreg(limitgroupelement.section, limitgroupelement.section_v), showreg(limitgroupelement.teststep, limitgroupelement.teststep_v),
      concat('limitgroup=', limitgroup.name, '\nname=', limitgroupelement.name, '\nlimit=limit:',
             if(g.bemerkungen = '',
                concat(showreg(g.domain, g.domain_v), '|', showreg(g.classes, g.classes_v), '|',
                       showreg(g.server, g.server_v), '|', showreg(g.section, g.section_v), '|',
                       showreg(g.teststep, g.teststep_v)),
                substring_index(g.bemerkungen, '\n', 1)),
             '\nmingood=', mingood, '\nwarngood=', warngood, '\nwarngoodlevel=', warngoodlevel,
             '\nsetclass=', coalesce((select sc.name from serverclasses as sc where sc.ID = resultingclassID), ''),
             '\nremark=', REPLACE(REPLACE(limitgroupelement.remark, '\\', '\\\\'), '\n', '\\n'), '\nactive=', limitgroupelement.active)
    from limitgroupelement
    join gautolimits as g on g.ID = groupautoID
    join limitgroup on limitgroup.ID = limitgroupID
    where limitgroupelement.ID = NEW.ID and limitgroupelement.TS = NEW.TS;
  elseif NEW.limtype = 'I' then
    insert into changeprot
      (groupID, changedtable, tableID, parentID, userID, username, action,
       domain, classes, server, section, teststep, newvalues)
    select limitgroup.groupID, 'limitgroupelement', limitgroupelement.ID, limitgroupID, coalesce(@userid,0),
      coalesce(@username,'SYSTEM'), 'update', showreg(limitgroupelement.domain, limitgroupelement.domain_v),
      showreg(limitgroupelement.classes, limitgroupelement.classes_v), showreg(limitgroupelement.server, limitgroupelement.server_v),
      showreg(limitgroupelement.section, limitgroupelement.section_v), showreg(limitgroupelement.teststep, limitgroupelement.teststep_v),
      concat('limitgroup=', limitgroup.name, '\nname=', limitgroupelement.name, '\nlimit=isalive:',
             if(g.bemerkungen = '',
                concat(showreg(g.domain, g.domain_v), '|', showreg(g.classes, g.classes_v), '|',
                       showreg(g.server, g.server_v), '|', showreg(g.section, g.section_v), '|',
                       showreg(g.teststep, g.teststep_v)),
                substring_index(g.bemerkungen, '\n', 1)),
             '\nmingood=', mingood, '\nwarngood=', warngood, '\nwarngoodlevel=', warngoodlevel,
             '\nsetclass=', coalesce((select sc.name from serverclasses as sc where sc.ID = resultingclassID), ''),
             '\nremark=', REPLACE(REPLACE(limitgroupelement.remark, '\\', '\\\\'), '\n', '\\n'), '\nactive=', limitgroupelement.active)
    from limitgroupelement
    join gautoisalive as g on g.ID = groupautoID
    join limitgroup on limitgroup.ID = limitgroupID
    where limitgroupelement.ID = NEW.ID and limitgroupelement.TS = NEW.TS;
  elseif NEW.limtype = 'C' then
    insert into changeprot
      (groupID, changedtable, tableID, parentID, userID, username, action,
       domain, classes, server, section, teststep, newvalues)
    select limitgroup.groupID, 'limitgroupelement', limitgroupelement.ID, limitgroupID, coalesce(@userid,0),
      coalesce(@username,'SYSTEM'), 'update', showreg(limitgroupelement.domain, limitgroupelement.domain_v),
      showreg(limitgroupelement.classes, limitgroupelement.classes_v), showreg(limitgroupelement.server, limitgroupelement.server_v),
      showreg(limitgroupelement.section, limitgroupelement.section_v), showreg(limitgroupelement.teststep, limitgroupelement.teststep_v),
      concat('limitgroup=', limitgroup.name, '\nname=', limitgroupelement.name, '\nlimit=combilimit:',
             if(g.bemerkungen = '',
                concat(showreg(g.domain, g.domain_v), '|', showreg(g.classes, g.classes_v), '|',
                       showreg(g.server, g.server_v), '|', showreg(g.section, g.section_v), '|',
                       showreg(g.teststep, g.teststep_v)),
                substring_index(g.bemerkungen, '\n', 1)),
             '\nmingood=', mingood, '\nwarngood=', warngood, '\nwarngoodlevel=', warngoodlevel,
             '\nsetclass=', coalesce((select sc.name from serverclasses as sc where sc.ID = resultingclassID), ''),
             '\nremark=', REPLACE(REPLACE(limitgroupelement.remark, '\\', '\\\\'), '\n', '\\n'), '\nactive=', limitgroupelement.active)
    from limitgroupelement
    join gautocombilimits as g on g.ID = groupautoID
    join limitgroup on limitgroup.ID = limitgroupID
    where limitgroupelement.ID = NEW.ID and limitgroupelement.TS = NEW.TS;
  end if;
end//

drop trigger if exists limitgroupelement_ai//
create trigger limitgroupelement_ai after insert on limitgroupelement
  for each row
begin
  if NEW.limtype = 'L' then
    insert into changeprot
      (groupID, changedtable, tableID, parentID, userID, username, action,
       domain, classes, server, section, teststep, newvalues)
    select limitgroup.groupID, 'limitgroupelement', NEW.ID, NEW.limitgroupID, coalesce(@userid,0),
      coalesce(@username,'SYSTEM'), 'insert', showreg(NEW.domain, NEW.domain_v),
      showreg(NEW.classes, NEW.classes_v), showreg(NEW.server, NEW.server_v),
      showreg(NEW.section, NEW.section_v), showreg(NEW.teststep, NEW.teststep_v),
      concat('limitgroup=', limitgroup.name, '\nname=', NEW.name, '\nlimit=limit:',
             if(g.bemerkungen = '',
                concat(showreg(g.domain, g.domain_v), '|', showreg(g.classes, g.classes_v), '|',
                       showreg(g.server, g.server_v), '|', showreg(g.section, g.section_v), '|',
                       showreg(g.teststep, g.teststep_v)),
                substring_index(g.bemerkungen, '\n', 1)),
             '\nmingood=', NEW.mingood, '\nwarngood=', NEW.warngood, '\nwarngoodlevel=', NEW.warngoodlevel,
             '\nsetclass=', coalesce((select sc.name from serverclasses as sc where sc.ID = NEW.resultingclassID), ''),
             '\nremark=', REPLACE(REPLACE(NEW.remark, '\\', '\\\\'), '\n', '\\n'), '\nactive=', NEW.active)
    from gautolimits as g, limitgroup
    where g.ID = NEW.groupautoID and limitgroup.ID = NEW.limitgroupID;
  elseif NEW.limtype = 'I' then
    insert into changeprot
      (groupID, changedtable, tableID, parentID, userID, username, action,
       domain, classes, server, section, teststep, newvalues)
    select limitgroup.groupID, 'limitgroupelement', NEW.ID, NEW.limitgroupID, coalesce(@userid,0),
      coalesce(@username,'SYSTEM'), 'insert', showreg(NEW.domain, NEW.domain_v),
      showreg(NEW.classes, NEW.classes_v), showreg(NEW.server, NEW.server_v),
      showreg(NEW.section, NEW.section_v), showreg(NEW.teststep, NEW.teststep_v),
      concat('limitgroup=', limitgroup.name, '\nname=', NEW.name, '\nlimit=isalive:',
             if(g.bemerkungen = '',
                concat(showreg(g.domain, g.domain_v), '|', showreg(g.classes, g.classes_v), '|',
                       showreg(g.server, g.server_v), '|', showreg(g.section, g.section_v), '|',
                       showreg(g.teststep, g.teststep_v)),
                substring_index(g.bemerkungen, '\n', 1)),
             '\nmingood=', NEW.mingood, '\nwarngood=', NEW.warngood, '\nwarngoodlevel=', NEW.warngoodlevel,
             '\nsetclass=', coalesce((select sc.name from serverclasses as sc where sc.ID = NEW.resultingclassID), ''),
             '\nremark=', REPLACE(REPLACE(NEW.remark, '\\', '\\\\'), '\n', '\\n'), '\nactive=', NEW.active)
    from gautoisalive as g, limitgroup
    where g.ID = NEW.groupautoID and limitgroup.ID = NEW.limitgroupID;
  elseif NEW.limtype = 'C' then
    insert into changeprot
      (groupID, changedtable, tableID, parentID, userID, username, action,
       domain, classes, server, section, teststep, newvalues)
    select limitgroup.groupID, 'limitgroupelement', NEW.ID, NEW.limitgroupID, coalesce(@userid,0),
      coalesce(@username,'SYSTEM'), 'insert', showreg(NEW.domain, NEW.domain_v),
      showreg(NEW.classes, NEW.classes_v), showreg(NEW.server, NEW.server_v),
      showreg(NEW.section, NEW.section_v), showreg(NEW.teststep, NEW.teststep_v),
      concat('limitgroup=', limitgroup.name, '\nname=', NEW.name, '\nlimit=combilimit:',
             if(g.bemerkungen = '',
                concat(showreg(g.domain, g.domain_v), '|', showreg(g.classes, g.classes_v), '|',
                       showreg(g.server, g.server_v), '|', showreg(g.section, g.section_v), '|',
                       showreg(g.teststep, g.teststep_v)),
                substring_index(g.bemerkungen, '\n', 1)),
             '\nmingood=', NEW.mingood, '\nwarngood=', NEW.warngood, '\nwarngoodlevel=', NEW.warngoodlevel,
             '\nsetclass=', coalesce((select sc.name from serverclasses as sc where sc.ID = NEW.resultingclassID), ''),
             '\nremark=', REPLACE(REPLACE(NEW.remark, '\\', '\\\\'), '\n', '\\n'), '\nactive=', NEW.active)
    from gautocombilimits as g, limitgroup
    where g.ID = NEW.groupautoID and limitgroup.ID = NEW.limitgroupID;
  end if;
end//


drop trigger if exists limitgroupelement_bd//
create trigger limitgroupelement_bd before delete on limitgroupelement
  for each row
begin
  insert into changeprot
    (groupID, changedtable, tableID, parentID, userID, username, action,
     domain, classes, server, section, teststep, newvalues)
  select limitgroup.groupID, 'limitgroupelement', OLD.ID, OLD.limitgroupID,
     coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'delete', showreg(OLD.domain, OLD.domain_v),
     showreg(OLD.classes, OLD.classes_v), showreg(OLD.server, OLD.server_v),
     showreg(OLD.section, OLD.section_v), showreg(OLD.teststep, OLD.teststep_v),
     concat('limitgroup=', limitgroup.name, '\nname=', OLD.name,
            coalesce(concat('\nremark=', REPLACE(REPLACE(@limitgroupremark, '\\', '\\\\'), '\n', '\\n')),
                     concat('\nremark=', REPLACE(REPLACE(@limitgroupelementremark, '\\', '\\\\'), '\n', '\\n')),''))
  from limitgroup
  where limitgroup.ID = OLD.limitgroupID;
end//

delimiter ;
